package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.IntegralLog;

/**
 * 积分日志Service接口
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
public interface IIntegralLogService 
{
    /**
     * 查询积分日志
     * 
     * @param id 积分日志主键
     * @return 积分日志
     */
    public IntegralLog selectIntegralLogById(Long id);

    /**
     * 查询积分日志列表
     * 
     * @param integralLog 积分日志
     * @return 积分日志集合
     */
    public List<IntegralLog> selectIntegralLogList(IntegralLog integralLog);

    /**
     * 新增积分日志
     * 
     * @param integralLog 积分日志
     * @return 结果
     */
    public int insertIntegralLog(IntegralLog integralLog);

    /**
     * 修改积分日志
     * 
     * @param integralLog 积分日志
     * @return 结果
     */
    public int updateIntegralLog(IntegralLog integralLog);

    /**
     * 批量删除积分日志
     * 
     * @param ids 需要删除的积分日志主键集合
     * @return 结果
     */
    public int deleteIntegralLogByIds(Long[] ids);

    /**
     * 删除积分日志信息
     * 
     * @param id 积分日志主键
     * @return 结果
     */
    public int deleteIntegralLogById(Long id);
}
